@@ -6,15 +6,16 @@ class Venue(models.Model):
     venue_name = models.TextField(max_length=80, primary_key=True)
     venue_path = models.TextField(max_length=255)
 
-    def __init__(self, venue_name, venue_path=os.getcwd()):
+    def __init__(self):
         self.venue_root = os.path.abspath(os.path.join(self.venue_path, self.venue_name))
-        self.uwsgi_ini = os.path.join(self.venue_root, 'backstage-%s-uwsgi.ini' % (self.venue_name))
-        self.acts_dir = os.path.join(self.venue_root, 'acts')
 
         if not os.path.exists(self.venue_root):
             print 'venue does not exist at %s' % self.venue_root
             self = None
             raise
+        self.uwsgi_ini = os.path.join(self.venue_root, 'backstage-%s-uwsgi.ini' % (self.venue_name))
+        self.acts_dir = os.path.join(self.venue_root, 'acts')
+
 
     def get_settings(self):
         """ import the venue's settings.py"""
